@@ -1,5 +1,5 @@
 import matplotlib.pyplot as plt
-from matplotlib.ticker import MaxNLocator
+from matplotlib.ticker import MaxNLocator, LogLocator
 from pymatgen.io.vasp.outputs import Vasprun
 from pymatgen.io.vasp.inputs import Poscar, Incar
 from pymatgen.electronic_structure.core import Spin, Orbital
@@ -469,7 +469,7 @@ class Dos:
 
         return groups, np.array(group_heights)
 
-    def _add_legend(self, ax, names, colors):
+    def _add_legend(self, ax, names, colors, fontsize=5, markersize=2):
         legend_lines = []
         legend_labels = []
         for name, color in zip(names, colors):
@@ -477,7 +477,7 @@ class Dos:
                 [0],
                 [0],
                 marker='o',
-                markersize=2,
+                markersize=markersize,
                 linestyle='',
                 color=color
             ))
@@ -501,7 +501,7 @@ class Dos:
             labels,
             ncol=1,
             loc='upper left',
-            fontsize=5,
+            fontsize=fontsize,
             bbox_to_anchor=(1, 1),
             borderaxespad=0,
             frameon=False,
@@ -1116,7 +1116,9 @@ class Dos:
             interface_line_color='white',
             interface_line_width=2,
             interface_line_style='--',
-            log_scale=False
+            log_scale=False,
+            contour=False,
+            levels=10,
     ):
         import matplotlib.colors as colors
         """
@@ -1156,16 +1158,50 @@ class Dos:
             atom_index = atom_index[lrange[0]:lrange[1]+1]
             densities = densities[:, lrange[0]:lrange[1]+1]
 
-        if energyaxis == 'y':
-            im = ax.pcolormesh(
-                atom_index,
-                energies,
-                densities,
-                cmap=cmap,
-                shading='gouraud',
-                norm=norm,
-                antialiased=antialiased,
+
+        if log_scale:
+            lev_exp = np.arange(
+                np.floor(np.log10(densities.min())-1),
+                np.ceil(np.log10(densities.max())+1),
             )
+            if len(lev_exp) >= levels:
+                pass
+            else:
+                if int(levels / len(lev_exp)) >= 3:
+                    lev_exp = np.arange(
+                        np.floor(np.log10(densities.min())-1),
+                        np.ceil(np.log10(densities.max())+1),
+                        0.25,
+                    )
+                else:
+                    lev_exp = np.arange(
+                        np.floor(np.log10(densities.min())-1),
+                        np.ceil(np.log10(densities.max())+1),
+                        0.5,
+                    )
+            levels = np.power(10, lev_exp)
+
+        if energyaxis == 'y':
+
+            if contour:
+                im = ax.contourf(
+                    atom_index, 
+                    energies,
+                    densities,
+                    cmap=cmap,
+                    levels=levels,
+                    norm=norm,
+                )
+            else:
+                im = ax.pcolormesh(
+                    atom_index,
+                    energies,
+                    densities,
+                    cmap=cmap,
+                    shading='gouraud',
+                    norm=norm,
+                    antialiased=antialiased,
+                )
             ax.xaxis.set_major_locator(MaxNLocator(integer=True))
 
 
@@ -1178,15 +1214,25 @@ class Dos:
                 )
 
         if energyaxis == 'x':
-            im = ax.pcolormesh(
-                energies,
-                atom_index,
-                np.transpose(densities),
-                cmap=cmap,
-                shading='gouraud',
-                norm=norm,
-                antialiased=antialiased,
-            )
+            if contour:
+                im = ax.contourf(
+                    energies,
+                    atom_index, 
+                    densities,
+                    cmap=cmap,
+                    levels=levels,
+                    norm=norm,
+                )
+            else:
+                im = ax.pcolormesh(
+                    energies,
+                    atom_index,
+                    np.transpose(densities),
+                    cmap=cmap,
+                    shading='gouraud',
+                    norm=norm,
+                    antialiased=antialiased,
+                )
             ax.yaxis.set_major_locator(MaxNLocator(integer=True))
 
             if interface_layer is not None:
